// Copyright 2021 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

/** @const {string} */
export const LEGACY_FILES_EXTENSION_ID = 'hhaomjibdihmijegdhdafkllkbggdgoj';

/**
 * App ID generated by the SWA framework.
 * @const {string}
 */
export const SWA_APP_ID = 'fkiggjmkendpmbegkagpmagjepfkpmeb';

/** @const {string} */
export const SWA_FILES_APP_HOST = 'file-manager';

/**
 * Special key for when we are showing search results. Search results do not
 * have a corresponding entry in the directory tree. As a result we need to
 * fake the PathComponent that represents the "current" directory. This constant
 * corresponds to the key field of the PathComponent object.
 * @const {string}
 */
export const SEARCH_RESULTS_KEY = 'fake-entry://search/';

/**
 * The URL of the legacy version of File Manager.
 * @const {!URL}
 */
export const LEGACY_FILES_APP_URL =
    new URL(`chrome-extension://${LEGACY_FILES_EXTENSION_ID}`);

/**
 * The URL of the System Web App version of File Manager.
 * @const {!URL}
 */
export const SWA_FILES_APP_URL = new URL(`chrome://${SWA_FILES_APP_HOST}`);

/**
 * The path to the File Manager icon.
 * @const {string}
 */
export const FILES_APP_ICON_PATH = 'common/images/icon96.png';

/**
 * @param {string=} path relative to the Files app root.
 * @return {!URL} The absolute URL for a path within the Files app.
 */
export function toFilesAppURL(path = '') {
  return new URL(path, SWA_FILES_APP_URL);
}

/**
 * @param {string=} path relative to the sandboxed page origin.
 * @return {!URL} The absolute URL.
 */
export function toSandboxedURL(path = '') {
  const SANDBOXED_URL = new URL(`chrome-untrusted://${SWA_FILES_APP_HOST}`);
  return new URL(path, SANDBOXED_URL);
}

/**
 * @return {!URL} The URL of the file that holds Files App icon.
 */
export function getFilesAppIconURL() {
  return toFilesAppURL(FILES_APP_ICON_PATH);
}
